@@ -15,31 +15,28 @@ class ViewProtobuf(base.View):
         "application/x-protobuffer",
     ]
 
-    @staticmethod
-    def is_available():
+    def is_available(self):
         try:
             p = subprocess.Popen(
                 ["protoc", "--version"],
                 stdout=subprocess.PIPE
             )
             out, _ = p.communicate()
-            return out.startswith("libprotoc")
+            return out.startswith(b"libprotoc")
         except:
             return False
 
-    def decode_protobuf(self, content):
+    def __call__(self, data, **metadata):
+        if not self.is_available():
+            raise NotImplementedError("protoc not found. Please make sure 'protoc' is available in $PATH.")
+
         # if Popen raises OSError, it will be caught in
         # get_content_view and fall back to Raw
         p = subprocess.Popen(['protoc', '--decode_raw'],
                              stdin=subprocess.PIPE,
                              stdout=subprocess.PIPE,
                              stderr=subprocess.PIPE)
-        out, err = p.communicate(input=content)
-        if out:
-            return out
-        else:
-            return err
-
-    def __call__(self, data, **metadata):
-        decoded = self.decode_protobuf(data)
+        decoded, _ = p.communicate(input=data)
+        if not decoded:
+            raise ValueError("Failed to parse input.")
         return "Protobuf", base.format_text(decoded)
