@@ -1,19 +1,16 @@
-from __future__ import absolute_import, print_function, division
-
 from mitmproxy import exceptions
 from mitmproxy import platform
-from mitmproxy import protocol
+from mitmproxy.proxy import protocol
 
 
 class TransparentProxy(protocol.Layer, protocol.ServerConnectionMixin):
 
     def __init__(self, ctx):
-        super(TransparentProxy, self).__init__(ctx)
-        self.resolver = platform.resolver()
+        super().__init__(ctx)
 
     def __call__(self):
         try:
-            self.server_conn.address = self.resolver.original_addr(self.client_conn.connection)
+            self.server_conn.address = platform.original_addr(self.client_conn.connection)
         except Exception as e:
             raise exceptions.ProtocolException("Transparent mode failure: %s" % repr(e))
 
@@ -21,5 +18,5 @@ class TransparentProxy(protocol.Layer, protocol.ServerConnectionMixin):
         try:
             layer()
         finally:
-            if self.server_conn:
+            if self.server_conn.connected():
                 self.disconnect()
