@@ -1,12 +1,11 @@
-from __future__ import print_function
 import sys
 import argparse
 import os
 import os.path
 
-from netlib import tcp
-from netlib import version
-from netlib.http import user_agents
+from mitmproxy.net import tcp
+from mitmproxy import version
+from mitmproxy.net.http import user_agents
 from . import pathoc, language
 
 
